Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(901)

Unified Diff: chrome/browser/chromeos/gdata/gdata_download_observer.cc

Issue 10877005: Rename GDataCache* to DriveCache* (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: rebase. Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/gdata/gdata_download_observer.cc
diff --git a/chrome/browser/chromeos/gdata/gdata_download_observer.cc b/chrome/browser/chromeos/gdata/gdata_download_observer.cc
index 55fb53afcc8db16602e2647669150f1f0787ab4e..6249a56af52d878bd0cb1785fb4281ba90e0de86 100644
--- a/chrome/browser/chromeos/gdata/gdata_download_observer.cc
+++ b/chrome/browser/chromeos/gdata/gdata_download_observer.cc
@@ -118,7 +118,7 @@ void SubstituteGDataDownloadPathInternal(Profile* profile,
DVLOG(1) << "SubstituteGDataDownloadPathInternal";
const FilePath gdata_tmp_download_dir = GetSystemService(profile)->cache()->
- GetCacheDirectoryPath(GDataCache::CACHE_TYPE_TMP_DOWNLOADS);
+ GetCacheDirectoryPath(DriveCache::CACHE_TYPE_TMP_DOWNLOADS);
// Swap the gdata path with a local path. Local path must be created
// on a blocking thread.
@@ -374,7 +374,7 @@ void GDataDownloadObserver::OnDownloadUpdated(DownloadItem* download) {
case DownloadItem::COMPLETE:
UploadDownloadItem(download);
- MoveFileToGDataCache(download);
+ MoveFileToDriveCache(download);
RemovePendingDownload(download);
break;
@@ -628,7 +628,7 @@ void GDataDownloadObserver::OnUploadComplete(
DCHECK(upload_data);
// Take ownership of the DocumentEntry from UploadFileInfo. This is used by
// GDataFileSystem::AddUploadedFile() to add the entry to GDataCache after the
// upload completes.
upload_data->set_entry(upload_file_info->entry.Pass());
@@ -636,7 +636,7 @@ void GDataDownloadObserver::OnUploadComplete(
upload_data->CompleteDownload();
}
-void GDataDownloadObserver::MoveFileToGDataCache(DownloadItem* download) {
+void GDataDownloadObserver::MoveFileToDriveCache(DownloadItem* download) {
DCHECK(BrowserThread::CurrentlyOn(BrowserThread::UI));
UploadingUserData* upload_data = GetUploadingUserData(download);
@@ -666,7 +666,7 @@ void GDataDownloadObserver::MoveFileToGDataCache(DownloadItem* download) {
upload_data->virtual_dir_path(),
entry.Pass(),
download->GetTargetFilePath(),
- GDataCache::FILE_OPERATION_MOVE,
+ DriveCache::FILE_OPERATION_MOVE,
base::Bind(&base::DoNothing));
}
}
@@ -628,7 +628,7 @@ void GDataDownloadObserver::OnUploadComplete(
DCHECK(upload_data);
// Take ownership of the DocumentEntry from UploadFileInfo. This is used by
- // GDataFileSystem::AddUploadedFile() to add the entry to GDataCache after the
+ // GDataFileSystem::AddUploadedFile() to add the entry to DriveCache after the
// upload completes.
upload_data->set_entry(upload_file_info->entry.Pass());
« no previous file with comments | « chrome/browser/chromeos/gdata/gdata_download_observer.h ('k') | chrome/browser/chromeos/gdata/gdata_file_system.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698